<?php
/*
 * Theme Settings
 * 
 * @package Hatch
 * @subpackage Template
 */
add_action( 'admin_menu', 'hatch_theme_admin_setup' );

function hatch_theme_admin_setup() {
    
	global $theme_settings_page;
	
	/* Get the theme settings page name */
	$theme_settings_page = 'appearance_page_theme-settings';

	/* Get the theme prefix. */
	$prefix = hybrid_get_prefix();

	/* Create a settings meta box only on the theme settings page. */
	add_action( 'load-appearance_page_theme-settings', 'hatch_theme_settings_meta_boxes' );

	/* Add a filter to validate/sanitize your settings. */
	add_filter( "sanitize_option_{$prefix}_theme_settings", 'hatch_theme_validate_settings' );
	
	/* Enqueue scripts */
	add_action( 'admin_enqueue_scripts', 'hatch_admin_scripts' );
}

/* Adds custom meta boxes to the theme settings page. */
function hatch_theme_settings_meta_boxes() {

	/* Add a custom meta box. */
	add_meta_box(
		'hatch-theme-meta-box',			// Name/ID
		__( 'General settings', hybrid_get_parent_textdomain() ),	// Label
		'hatch_theme_meta_box',			// Callback function
		'appearance_page_theme-settings',		// Page to load on, leave as is
		'normal',					// Which meta box holder?
		'high'					// High/low within the meta box holder
	);

	/* Add additional add_meta_box() calls here. */
}

/* Function for displaying the meta box. */
function hatch_theme_meta_box() { ?>

	<table class="form-table">
	    
		<!-- Favicon upload -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'hatch_favicon_url' ); ?>"><?php _e( 'Favicon:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				<input type="text" id="<?php echo hybrid_settings_field_id( 'hatch_favicon_url' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_favicon_url' ); ?>" value="<?php echo esc_attr( hybrid_get_setting( 'hatch_favicon_url' ) ); ?>" style="width: 500px" />
				<input id="hatch_favicon_upload_button" class="button" type="button" value="Upload" />
				<br />
				<span class="description"><?php _e( 'Upload favicon image (recommended max size: 32x32).', hybrid_get_parent_textdomain() ); ?></span>
				
				<?php /* Display uploaded image */
				if ( hybrid_get_setting( 'hatch_favicon_url' ) ) { ?>
                    <p style="max-width: 32px;"><img src="<?php echo hybrid_get_setting( 'hatch_favicon_url' ); ?>" alt="" style="max-width: 100%;"/></p>
				<?php } ?>
			</td>
		</tr>
		
		<!-- Logo upload -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'hatch_logo_url' ); ?>"><?php _e( 'Logo:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				<input type="text" id="<?php echo hybrid_settings_field_id( 'hatch_logo_url' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_logo_url' ); ?>" value="<?php echo esc_attr( hybrid_get_setting( 'hatch_logo_url' ) ); ?>" style="width: 500px" />
				<input id="hatch_logo_upload_button" class="button" type="button" value="Upload" />
				<br />
				<span class="description"><?php _e( 'Upload logo image (recommended max width: 200px).', hybrid_get_parent_textdomain() ); ?></span>
				
				<?php /* Display uploaded image */
				if ( hybrid_get_setting( 'hatch_logo_url' ) ) { ?>
                    <p style="max-width: 200px;"><img src="<?php echo hybrid_get_setting( 'hatch_logo_url' ); ?>" alt="" style="max-width: 100%;"/></p>
				<?php } ?>
			</td>
		</tr>
		
		<!-- Author Description -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'hatch_author_bio' ); ?>"><?php _e( 'Author:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				
				<?php /* Set arguments for the authors dropdown list */
				$author_bio_id = hybrid_settings_field_id( 'hatch_author_bio' );
				$author_bio_name = hybrid_settings_field_name( 'hatch_author_bio' );
				$author_bio_selected = hybrid_get_setting( 'hatch_author_bio' );
				
				$args = array(
					'id' => $author_bio_id,
					'name' => $author_bio_name,
					'selected' => $author_bio_selected
				);
				
				/* Display the authors dropdown list */
				wp_dropdown_users( $args ); ?>
				
				<span class="description"><?php _e( 'Whose biography to display on the home page?', hybrid_get_parent_textdomain() ); ?></span>
				
			</td>
		</tr>		
		
		<!-- Font family -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'hatch_font_family' ); ?>"><?php _e( 'Font family:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
			    <select id="<?php echo hybrid_settings_field_id( 'hatch_font_family' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_font_family' ); ?>">
				<option value="Arial" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Arial' ? 'selected="selected"' : '' ?>> <?php echo __( 'Arial', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Verdana" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Verdana' ? 'selected="selected"' : '' ?>> <?php echo __( 'Verdana', hybrid_get_parent_textdomain() ) ?> </option>				
				<option value="Bitter" <?php echo hybrid_get_setting( 'hatch_font_family', 'Bitter' ) == 'Bitter' ? 'selected="selected"' : '' ?>> <?php echo __( 'Bitter', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Georgia" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Georgia' ? 'selected="selected"' : '' ?>> <?php echo __( 'Georgia', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Droid Serif" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Droid Serif' ? 'selected="selected"' : '' ?>> <?php echo __( 'Droid Serif', hybrid_get_parent_textdomain() ) ?> </option>				
				<option value="Helvetica" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Helvetica' ? 'selected="selected"' : '' ?>> <?php echo __( 'Helvetica', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Istok Web" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Istok Web' ? 'selected="selected"' : '' ?>> <?php echo __( 'Istok Web', hybrid_get_parent_textdomain() ) ?> </option>			
				<option value="Lucida Sans Unicode" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Lucida Sans Unicode' ? 'selected="selected"' : '' ?>> <?php echo __( 'Lucida Sans Unicode', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Droid Sans" <?php echo hybrid_get_setting( 'hatch_font_family' ) == 'Droid Sans' ? 'selected="selected"' : '' ?>> <?php echo __( 'Droid Sans', hybrid_get_parent_textdomain() ) ?> </option>
			    </select>
			</td>
		</tr>
		
		<!-- Font size -->
		<tr>
			<th>
			    <label for="<?php echo hybrid_settings_field_id( 'hatch_font_size' ); ?>"><?php _e( 'Font size:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
			    <select id="<?php echo hybrid_settings_field_id( 'hatch_font_size' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_font_size' ); ?>">
				<option value="16" <?php echo hybrid_get_setting( 'hatch_font_size', '16' ) == '16' ? 'selected="selected"' : '' ?>> <?php echo __( 'default', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="17" <?php echo hybrid_get_setting( 'hatch_font_size', '17' ) == '17' ? 'selected="selected"' : '' ?>> <?php echo __( '17', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="16" <?php echo hybrid_get_setting( 'hatch_font_size', '16' ) == '16' ? 'selected="selected"' : '' ?>> <?php echo __( '16', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="15" <?php echo hybrid_get_setting( 'hatch_font_size' ) == '15' ? 'selected="selected"' : '' ?>> <?php echo __( '15', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="14" <?php echo hybrid_get_setting( 'hatch_font_size' ) == '14' ? 'selected="selected"' : '' ?>> <?php echo __( '14', hybrid_get_parent_textdomain() ) ?> </option>
			    </select>
			    <span class="description"><?php _e( 'The base font size in pixels.', hybrid_get_parent_textdomain() ); ?></span>
			</td>
		</tr>		
	    
		<!-- Link color -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'hatch_link_color' ); ?>"><?php _e( 'Link color:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				<?php if ( hybrid_get_setting( 'hatch_link_color' ) ) { ?>
					<input type="text" id="<?php echo hybrid_settings_field_id( 'hatch_link_color' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_link_color' ); ?>" size="8" value="<?php echo esc_attr( hybrid_get_setting( 'hatch_link_color' ) ); ?>" data-hex="true" />
				<?php } else { ?>
					<input type="text" id="<?php echo hybrid_settings_field_id( 'hatch_link_color' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_link_color' ); ?>" size="8" value="#64a2d8" data-hex="true" />
				<?php } ?>	
				<div id="colorpicker_link_color"></div>
				<span class="description"><?php _e( 'Set the theme link color.', hybrid_get_parent_textdomain() ); ?></span>
			</td>
		</tr>	    

		<!-- Custom CSS -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'hatch_custom_css' ); ?>"><?php _e( 'Custom CSS:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				<textarea id="<?php echo hybrid_settings_field_id( 'hatch_custom_css' ); ?>" name="<?php echo hybrid_settings_field_name( 'hatch_custom_css' ); ?>" cols="60" rows="8" style="width: 98%;"><?php echo wp_htmledit_pre( stripslashes( hybrid_get_setting( 'hatch_custom_css' ) ) ); ?></textarea>
				<span class="description"><?php _e( 'Add your custom CSS here. It would overwrite any default or custom theme settings.', hybrid_get_parent_textdomain() ); ?></span>
			</td>
		</tr>

		<!-- End custom form elements. -->
	</table><!-- .form-table --><?php
	
}

/* Validate theme settings. */
function hatch_theme_validate_settings( $input ) {
	
    $input['hatch_favicon_url'] = esc_url_raw( $input['hatch_favicon_url'] );   
    $input['hatch_logo_url'] = esc_url_raw( $input['hatch_logo_url'] );
	$input['hatch_author_bio'] = wp_filter_nohtml_kses( $input['hatch_author_bio'] );
	$input['hatch_font_family'] = wp_filter_nohtml_kses( $input['hatch_font_family'] );
	$input['hatch_font_size'] = wp_filter_nohtml_kses( $input['hatch_font_size'] );
    $input['hatch_link_color'] = wp_filter_nohtml_kses( $input['hatch_link_color'] );   
    $input['hatch_custom_css'] = wp_filter_nohtml_kses( $input['hatch_custom_css'] );

    /* Return the array of theme settings. */
    return $input;
}

/* Enqueue scripts (and related stylesheets) */
function hatch_admin_scripts( $hook_suffix ) {
    
    global $theme_settings_page;
	
    if ( $theme_settings_page == $hook_suffix ) {
	    
	    /* Enqueue Scripts */
	    wp_register_script( 'functions-admin', get_template_directory_uri() . '/admin/functions-admin.js', array( 'jquery', 'media-upload', 'thickbox', 'farbtastic' ), '1.0', false );
	    wp_enqueue_script( 'functions-admin' );
	    
	    /* Enqueue Styles */
	    wp_enqueue_style( 'functions-admin', get_template_directory_uri() . '/admin/functions-admin.css', false, 1.0, 'screen' );
	    wp_enqueue_style( 'farbtastic' );
    }
}


?>